The CapProvider<P> trait — unified capability access with optional scope enforcement.
CapProvider<P> generalizes Has<P> to support both unscoped
capabilities (which always succeed) and scoped capabilities
(Attenuated<P, S>) which check the target against
a scope before granting access.
Traits
- CapProvider
- A type that can provide a capability token for permission
P, possibly after performing a scope check against the target.